templatetools
=============

.. automodule:: abjad.tools.templatetools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.templatetools.GroupedRhythmicStavesScoreTemplate.GroupedRhythmicStavesScoreTemplate
      ~abjad.tools.templatetools.GroupedStavesScoreTemplate.GroupedStavesScoreTemplate
      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate
      ~abjad.tools.templatetools.StringQuartetScoreTemplate.StringQuartetScoreTemplate
      ~abjad.tools.templatetools.TwoStaffPianoScoreTemplate.TwoStaffPianoScoreTemplate
